@@ -10,17 +10,22 @@ import typing_extensions
 
 import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_ecs._jsii
+import aws_cdk.aws_efs._jsii
 import aws_cdk.aws_elasticloadbalancingv2._jsii
+import aws_cdk.aws_iam._jsii
+import aws_cdk.aws_logs._jsii
+import aws_cdk.aws_rds._jsii
 import aws_cdk.aws_route53._jsii
 import aws_cdk.aws_route53_targets._jsii
+import aws_cdk.aws_secretsmanager._jsii
 import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "cdk-fargate-patterns",
-    "0.1.2",
+    "0.1.3",
     __name__[0:-6],
-    "cdk-fargate-patterns@0.1.2.jsii.tgz",
+    "cdk-fargate-patterns@0.1.3.jsii.tgz",
 )
 
 __all__ = [
